@@ -1,4 +1,6 @@
 import asyncio
+
+
 class AuthResource:
     def __init__(self, client):
         self._client = client
@@ -8,13 +10,14 @@ class AuthResource:
         A call to GET /auth/profile to initially authenticate the user.
         """
         response = self._client._get("/auth/profile")
-        
+
         # Set the user_id if successful
-        if response and isinstance(response, dict) and 'user_id' in response:
-            self._client._user = response['user_id']
-        
+        if response and isinstance(response, dict) and "user_id" in response:
+            self._client._user = response["user_id"]
+
         return response
-    
+
+
 class AsyncAuthResource:
     def __init__(self, client):
         self._client = client
@@ -30,13 +33,11 @@ class AsyncAuthResource:
             task = loop.create_task(self._client._get("/auth/profile"))
             # Run the task to completion
             result = loop.run_until_complete(task)
-            
+
             # Set the user_id if successful
-            if result and isinstance(result, dict) and 'user_id' in result:
-                self._client._user = result['user_id']
-            
+            if result and isinstance(result, dict) and "user_id" in result:
+                self._client._user = result["user_id"]
+
             return result
         finally:
             loop.close()
-
-
